# Calibration of Material

The calibration commands are used for material calibration.

## Create material calibrations

```{eval-rst}
.. autoclass:: abaqus.Calibration.CalibrationModel.CalibrationModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Calibration.Calibration.Calibration
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Calibration.Behavior.Behavior
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Calibration.DataSet.DataSet
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
